Package: polywog
Title: Bootstrapped Basis Regression with Oracle Model Selection
Version: 0.4-2
Date: 2025-05-13
Authors@R: c(
    person("Brenton", "Kenkel", email = "brenton.kenkel@gmail.com", role = c("aut", "cre")),
    person("Curtis S.", "Signorino", role = "aut"))
Description: Routines for flexible functional form estimation via basis
    regression, with model selection via the adaptive LASSO or SCAD to prevent
    overfitting.
License: GPL (>= 2)
URL: https://github.com/brentonk/polywog
Depends: miscTools (>= 0.6-12)
Imports: foreach, Formula, glmnet (>= 1.9-5), iterators, Matrix, ncvreg
        (>= 2.4-0), Rcpp (>= 0.11.0), stringr
LinkingTo: Rcpp
Suggests: carData, lattice, rgl
RoxygenNote: 7.3.2
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2025-05-13 22:08:11 UTC; brenton
Author: Brenton Kenkel [aut, cre],
  Curtis S. Signorino [aut]
Maintainer: Brenton Kenkel <brenton.kenkel@gmail.com>
Repository: CRAN
Date/Publication: 2025-05-13 22:20:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 09:30:41 UTC; unix
Archs: polywog.so.dSYM
