# Generated by roxygen2: do not edit by hand

S3method(margEff,polywog)
S3method(model.frame,polywog)
S3method(model.matrix,polywog)
S3method(plot,margEff.polywog)
S3method(plot,polywog)
S3method(plot,preplot.polywog)
S3method(predict,polywog)
S3method(print,polywog)
S3method(print,summary.margEff.polywog)
S3method(print,summary.polywog)
S3method(summary,margEff.polywog)
S3method(summary,polywog)
S3method(vcov,polywog)
export(bootPolywog)
export(control.bp)
export(cv.polywog)
export(polywog)
export(predVals)
import(Formula)
import(foreach)
import(glmnet)
import(iterators)
import(ncvreg)
importFrom(Matrix,Matrix)
importFrom(Rcpp,sourceCpp)
importFrom(graphics,bxp)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(miscTools,margEff)
importFrom(stats,.checkMFClasses)
importFrom(stats,.getXlevels)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,delete.response)
importFrom(stats,density)
importFrom(stats,dlogis)
importFrom(stats,formula)
importFrom(stats,glm.fit)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,model.weights)
importFrom(stats,na.pass)
importFrom(stats,napredict)
importFrom(stats,predict)
importFrom(stats,printCoefmat)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,terms)
importFrom(stats,update)
importFrom(stats,var)
importFrom(stats,vcov)
importFrom(stringr,str_split)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
importMethodsFrom(Matrix,rowMeans)
importMethodsFrom(Matrix,t)
useDynLib(polywog, .registration = TRUE)
