polywog
=======

`polywog` is an R package by [Brenton Kenkel](https://bkenkel.com/) and
[Curtis Signorino](https://www.sas.rochester.edu/psc/signorino/) containing
routines for flexible functional form estimation via basis regression with
oracle-penalized model selection.  You can install the most recent stable
version of the package
[from CRAN](https://cran.r-project.org/package=polywog) by
running

```r
install.packages("polywog")
```

in an R console.

To request a feature or report a bug, please visit the package's [project page
on Github](https://github.com/brentonk/polywog).  The package's
[change log](https://github.com/brentonk/polywog/blob/master/NEWS.md)
can also be viewed there.
